@@ -9,7 +9,7 @@ from gv_pubsub.pubsub import PubSub
 from gv_requests.requests import Requests
 from gv_utils.asyncio import check_event_loop
 from gv_utils.datetime import datetime
-from gv_utils.enums import MessageKind, AttId
+from gv_utils.enums import MessageKind
 from gv_utils.geometry import BaseGeometry
 from gv_utils.logger import Logger
 
@@ -18,7 +18,7 @@ class Service:
     samplings = {MessageKind.karrusrd: 1 * 60, MessageKind.metropme: 1 * 60, MessageKind.tomtomfcd: 1 * 60}
 
     def __init__(self, logger: Logger, futures: list = None, callbacks: dict = None,
-                 custom_data_decoder: Callable = None, offlineprefix: bool = None) -> None:
+                 custom_data_decoder: Callable = None, offlineprefix: str = None) -> None:
         if futures is None:
             futures = []
         if callbacks is None:
@@ -84,71 +84,64 @@ class Service:
         await self.pubsub.subscribe(datakind, callback)
 
     async def _get_data_point(self, datapointeids: list = None, datatypeeids: list = None,
-                              area: BaseGeometry = None) -> dict:
+                              area: BaseGeometry = None) -> list:
         return await self.requests.get_data_point(datapointeids, datatypeeids, area)
 
-    async def _get_road(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
+    async def _get_road(self, roadeids: list = None, area: BaseGeometry = None) -> list:
         return await self.requests.get_road(roadeids, area)
 
-    async def _get_zone_point(self, zoneeids: list = None, area: BaseGeometry = None) -> dict:
+    async def _get_road_center(self, roadeids: list = None, area: BaseGeometry = None) -> list:
+        return await self.requests.get_road_center(roadeids, area)
+
+    async def _get_turn_ratio(self, fromroad: str = None, toroad: str = None) -> list:
+        return await self.requests.get_turn_ratio(fromroad, toroad)
+
+    async def _get_zone_point(self, zoneeids: list = None, area: BaseGeometry = None) -> list:
         return await self.requests.get_zone_point(zoneeids, area)
 
-    async def _get_road_data_point(self, datatype: str = None, area: BaseGeometry = None) -> dict:
+    async def _get_road_data_point(self, datatype: str = None, area: BaseGeometry = None) -> list:
         return await self.requests.get_road_data_point(datatype, area)
 
     async def _get_data_point_data_quality(self, fromdatetime: datetime, todatetime: datetime = None,
                                            datapointeids: list = None, datatypeeids: list = None, period: str = None,
-                                           sampling: str = None, window: str = None) -> dict:
+                                           sampling: str = None, window: str = None) -> list:
         return await self.requests.get_data_point_data_quality(fromdatetime, todatetime, datapointeids, datatypeeids,
                                                                period, sampling, window)
 
     async def _get_data_type_data_quality(self, fromdatetime: datetime, todatetime: datetime = None,
                                           datatypeeids: list = None, period: str = None, sampling: str = None,
-                                          window: str = None) -> dict:
+                                          window: str = None) -> list:
         return await self.requests.get_data_type_data_quality(fromdatetime, todatetime, datatypeeids, period, sampling,
                                                               window)
 
     async def _get_road_data_quality(self, fromdatetime: datetime, todatetime: datetime = None, roadeids: list = None,
-                                     period: str = None, sampling: str = None, window: str = None) -> dict:
+                                     period: str = None, sampling: str = None, window: str = None) -> list:
         return await self.requests.get_road_data_quality(fromdatetime, todatetime, roadeids, period, sampling, window)
 
     async def _get_data_point_imputed_indicator(self, indicator: str, fromdatetime: datetime,
                                                 todatetime: datetime = None, datapointeids: list = None,
                                                 datatypeeids: list = None, period: str = None, sampling: str = None,
-                                                window: str = None) -> dict:
+                                                window: str = None) -> list:
         return await self.requests.get_data_point_imputed_indicator(indicator, todatetime, fromdatetime, datapointeids,
                                                                     datatypeeids, period, sampling, window)
 
     async def _get_data_point_indicator(self, indicator: str, fromdatetime: datetime, todatetime: datetime = None,
                                         datapointeids: list = None, datatypeeids: list = None, period: str = None,
-                                        sampling: str = None, window: str = None) -> dict:
+                                        sampling: str = None, window: str = None) -> list:
         return await self.requests.get_data_point_indicator(indicator, fromdatetime, todatetime, datapointeids,
                                                             datatypeeids, period, sampling, window)
 
     async def _get_road_indicator(self, indicator: str, fromdatetime: datetime, todatetime: datetime = None,
                                   roadeids: list = None, period: str = None, sampling: str = None,
-                                  window: str = None) -> dict:
+                                  window: str = None) -> list:
         return await self.requests.get_road_indicator(indicator, fromdatetime, todatetime, roadeids, period, sampling,
                                                       window)
 
     async def _get_zone_travel_time(self, frompointeid: str, topointeid: str, fromdatetime: datetime,
-                                    todatetime: datetime = None, period: str = None, sampling: str = None) -> dict:
+                                    todatetime: datetime = None, period: str = None, sampling: str = None) -> list:
         return await self.requests.get_zone_travel_time(frompointeid, topointeid, fromdatetime, todatetime, period,
                                                         sampling)
 
-    async def _get_road_center(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
-        return await self.requests.get_road_center(roadeids, area)
-
-    async def _get_turn_ratio(self, fromroad: str = None, toroad: str = None) -> dict:
-        return await self.requests.get_turn_ratio(fromroad, toroad)
-
-    @staticmethod
-    def _get_data_type_eid_from_data_points(datapoints: dict) -> str:
-        datapointeid, datapoint = datapoints.popitem()
-        datatypeeid = datapoint[AttId.datatype]
-        datapoints[datapointeid] = datapoint
-        return datatypeeid
-
 
 def start(Application, threaded=False):
     if threaded:
