@@ -39,7 +39,7 @@ def encode_pandas(dataframe: pd.DataFrame) -> str:
         except:
             pass
     dataframe.replace(MessageData.nan, '', inplace=True)
-    return dataframe.to_csv(sep=MessageData.csvseparator)
+    return dataframe.to_csv(sep=MessageData.csvseparator, quotechar=MessageData.csvquote)
 
 
 async def encode_message(message: Any) -> str:
@@ -59,7 +59,7 @@ def object_hook(obj: dict, custom_data_decoder: Callable = None) -> dict:
     for key in obj:
         val = None
         if key == Message.kind:
-            val = __remove_past_prefix(obj[key])
+            val = obj[key]
         elif key == Message.timestamp:
             val = from_timestamp(obj[key])
         elif key == Message.data:
@@ -105,30 +105,8 @@ def merge_types(types: list) -> str:
     return MessageKind.separator.join(types)
 
 
-def __remove_past_prefix(messagekind: str) -> str:
-    sep = MessageKind.separator
-    splited = messagekind.split(sep)
-    return messagekind if splited[0] != MessageKind.past else sep.join(splited[1:])
-
-
-def remove_data_type_suffix_from_message_kind(messagekind: str) -> str:
-    sep = MessageKind.separator
-    splited = messagekind.split(sep)
-    return messagekind if splited[0] != MessageKind.datapoint else sep.join(splited[:-1])
-
-
-def remove_data_point_from_message_kind(messagekind: str) -> str:
-    sep = MessageKind.separator
-    splited = messagekind.split(sep)
-    if len(splited) >= 3:
-        try:
-            splited.remove(MessageKind.datapoint)
-        except ValueError:
-            pass
-    return sep.join(splited)
-
-
-def data_to_gen(data: Any, datadate: datetime = None, sampletimefield: str = None) -> Generator[dict, None, None]:
+def data_to_gen(data: Any, datadate: datetime = None, sampletimefield: str = None,
+                indexname: str = AttId.eid) -> Generator[dict, None, None]:
     gen = None
     if isinstance(data, dict):
         gen = data_dict_to_gen
@@ -137,18 +115,18 @@ def data_to_gen(data: Any, datadate: datetime = None, sampletimefield: str = Non
     elif isinstance(data, pd.DataFrame):
         gen = data_pandas_to_gen
     if gen is not None:
-        data = gen(data, datadate, sampletimefield)
+        data = gen(data, datadate, sampletimefield, indexname)
     return data
 
 
 def data_dict_to_gen(datadict: dict, datadate: datetime = None,
-                     sampletimefield: str = None) -> Generator[Any, None, None]:
+                     sampletimefield: str = None, indexname: str = AttId.eid) -> Generator[Any, None, None]:
     for eid, values in datadict.items():
-        yield expand_dict(values, eid, datadate, sampletimefield)
+        yield expand_dict(values, eid, datadate, sampletimefield, indexname)
 
 
-def data_csv_to_gen(datacsv: str, datadate: datetime = None,
-                    sampletimefield: str = None) -> Generator[Any, None, None]:
+def data_csv_to_gen(datacsv: str, datadate: datetime = None, sampletimefield: str = None,
+                    indexname: str = AttId.eid) -> Generator[Any, None, None]:
     def _get_line(rawline):
         return rawline.strip(os.linesep).split(MessageData.csvseparator)
 
@@ -172,21 +150,26 @@ def data_csv_to_gen(datacsv: str, datadate: datetime = None,
                 except (AttributeError, json.decoder.JSONDecodeError):
                     pass
             values[header[i]] = value
-        yield expand_dict(values, eid, datadate, sampletimefield)
+        yield expand_dict(values, eid, datadate, sampletimefield, indexname)
     csvbuffer.close()
 
 
-def data_pandas_to_gen(dataframe: pd.DataFrame, sampletimefield: str = None) -> Generator[Any, None, None]:
-    yield from data_dict_to_gen(data_pandas_to_dict(dataframe), from_timestamp(int(dataframe.index.name)),
-                                sampletimefield)
+def data_pandas_to_gen(dataframe: pd.DataFrame, sampletimefield: str = None,
+                       indexname: str = AttId.eid) -> Generator[Any, None, None]:
+    yield from data_dict_to_gen(data_pandas_to_dict(dataframe), from_timestamp(get_dataframe_timestamp(dataframe)),
+                                sampletimefield, indexname)
 
 
 def data_pandas_to_dict(dataframe: pd.DataFrame) -> dict:
     return dataframe.to_dict(orient='index')
 
 
-def expand_dict(values: dict, eid: str, datadate: datetime, sampletimefield: str) -> dict:
-    extradict = {AttId.eid: eid}
+def expand_dict(values: dict, eid: str, datadate: datetime, sampletimefield: str, indexname: str = AttId.eid) -> dict:
+    extradict = {indexname: eid}
     if sampletimefield is not None and datadate is not None:
         extradict[sampletimefield] = datadate
     return dict(**values, **extradict)
+
+
+def get_dataframe_timestamp(df: pd.DataFrame) -> int:
+    return int(df.index.name)
